Description: Fix spelling errors
Origin: vendor
Forwarded: https://rt.cpan.org/Public/Bug/Display.html?id=122971
Author: Angel Abad <angel@debian.org>
Last-Update: 2017-09-06

--- a/lib/IO/Socket/Socks.pm
+++ b/lib/IO/Socket/Socks.pm
@@ -2185,7 +2185,7 @@
 
 This is a class method to start socks handshake on already connected socket. This
 will bless passed $socket to IO::Socket::Socks class. %cfg is like hash in the constructor.
-Only options listed below makes sence:
+Only options listed below makes sense:
 
   Timeout
   ConnectAddr
@@ -2273,7 +2273,7 @@
 Allows one to execute socks command on already opened socket. Thus you
 can create socks chain. For example see L</EXAMPLES> section.
 
 %cfg is like hash in the constructor. Only options listed below makes sence:
 
   ConnectAddr
   ConnectPort
@@ -2273,7 +2273,7 @@
 can create socks chain. For example see L</EXAMPLES> section.
 
-%cfg is like hash in the constructor. Only options listed below makes sence:
+%cfg is like hash in the constructor. Only options listed below makes sense:
 
   ConnectAddr
